==> ejc-law-impl-3.0.0-20221108.082218-21-sources.jar: com/ejianc/business/law/bean/PartyEntity.java <==
package com.ejianc.business.law.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 当事人登记表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_law_party")
public class PartyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="operator_code")
    private String operatorCode; // 经办人联系方式
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="zhu_id")
    private Long zhuId; // 主表ID
    @TableField(value="party_name")
    private String partyName; // 当事人名称
    @TableField(value="party_type_id")
    private Long partyTypeId; // 诉讼地位
    @TableField(value="party_type_name")
    private String partyTypeName; // 诉讼地位名称
    @TableField(value="party_code")
    private String partyCode; // 当事人联系方式
    @TableField(value="agent_name")
    private String agentName; // 代理人名称
    @TableField(value="agent_org_name")
    private String agentOrgName; // 代理人单位
    @TableField(value="agent_phone")
    private String agentPhone; // 代理人联系方式
    @TableField(value="agent_org_id")
    private Long agentOrgId; // 代理单位id
    @TableField(value="party_project_id")
    private Long partyProjectId; // 当事项目id
    @TableField(value="party_project_name")
    private String partyProjectName; // 当事项目名称
    @TableField(value="linkman_id")
    private Long linkmanId; // 联系人id
    @TableField(value="linkman_name")
    private String linkmanName; // 联系人名称
    @TableField(value="is_main_suit")
    private String isMainSuit; // 是否主诉方
    @TableField(value = "party_id")
    private Long partyId;//当事人id
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    public String getPartyName() {
        return partyName;
    }

    public void setPartyName(String partyName) {
        this.partyName = partyName;
    }
    public Long getPartyTypeId() {
        return partyTypeId;
    }

    public void setPartyTypeId(Long partyTypeId) {
        this.partyTypeId = partyTypeId;
    }
    public String getPartyTypeName() {
        return partyTypeName;
    }

    public void setPartyTypeName(String partyTypeName) {
        this.partyTypeName = partyTypeName;
    }
    public String getPartyCode() {
        return partyCode;
    }

    public void setPartyCode(String partyCode) {
        this.partyCode = partyCode;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public String getAgentOrgName() {
        return agentOrgName;
    }

    public void setAgentOrgName(String agentOrgName) {
        this.agentOrgName = agentOrgName;
    }
    public String getAgentPhone() {
        return agentPhone;
    }

    public void setAgentPhone(String agentPhone) {
        this.agentPhone = agentPhone;
    }


    public Long getAgentOrgId() {
        return agentOrgId;
    }

    public void setAgentOrgId(Long agentOrgId) {
        this.agentOrgId = agentOrgId;
    }

    public Long getPartyProjectId() {
        return partyProjectId;
    }

    public void setPartyProjectId(Long partyProjectId) {
        this.partyProjectId = partyProjectId;
    }

    public String getPartyProjectName() {
        return partyProjectName;
    }

    public void setPartyProjectName(String partyProjectName) {
        this.partyProjectName = partyProjectName;
    }

    public Long getLinkmanId() {
        return linkmanId;
    }

    public void setLinkmanId(Long linkmanId) {
        this.linkmanId = linkmanId;
    }

    public String getLinkmanName() {
        return linkmanName;
    }

    public void setLinkmanName(String linkmanName) {
        this.linkmanName = linkmanName;
    }

    public String getIsMainSuit() {
        return isMainSuit;
    }

    public void setIsMainSuit(String isMainSuit) {
        this.isMainSuit = isMainSuit;
    }

    public Long getPartyId() {
        return partyId;
    }

    public void setPartyId(Long partyId) {
        this.partyId = partyId;
    }
}

==> ejc-law-impl-3.0.0-20240726.062554-88-sources.jar: com/ejianc/business/law/bean/PartyEntity.java <==
package com.ejianc.business.law.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 当事人登记表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_law_party")
public class PartyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="operator_code")
    private String operatorCode; // 经办人联系方式
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="zhu_id")
    private Long zhuId; // 主表ID
    @TableField(value="party_name")
    private String partyName; // 当事人名称
    @TableField(value="party_type_id")
    private Long partyTypeId; // 诉讼地位
    @TableField(value="party_type_name")
    private String partyTypeName; // 诉讼地位名称
    @TableField(value="party_code")
    private String partyCode; // 当事人联系方式
    @TableField(value="agent_name")
    private String agentName; // 代理人名称
    @TableField(value="agent_org_name")
    private String agentOrgName; // 代理人单位
    @TableField(value="agent_phone")
    private String agentPhone; // 代理人联系方式
    @TableField(value="agent_org_id")
    private Long agentOrgId; // 代理单位id
    @TableField(value="party_project_id")
    private Long partyProjectId; // 当事项目id
    @TableField(value="party_project_name")
    private String partyProjectName; // 当事项目名称
    @TableField(value="linkman_id")
    private Long linkmanId; // 联系人id
    @TableField(value="linkman_name")
    private String linkmanName; // 联系人名称
    @TableField(value="is_main_suit")
    private String isMainSuit; // 是否主诉方
    @TableField(value = "party_id")
    private Long partyId;//当事人id
    @TableField(value = "agent_id")
    private Long agentId;//代理单位登记子表id
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getOperatorCode() {
        return operatorCode;
    }

    public void setOperatorCode(String operatorCode) {
        this.operatorCode = operatorCode;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getZhuId() {
        return zhuId;
    }

    public void setZhuId(Long zhuId) {
        this.zhuId = zhuId;
    }
    public String getPartyName() {
        return partyName;
    }

    public void setPartyName(String partyName) {
        this.partyName = partyName;
    }
    public Long getPartyTypeId() {
        return partyTypeId;
    }

    public void setPartyTypeId(Long partyTypeId) {
        this.partyTypeId = partyTypeId;
    }
    public String getPartyTypeName() {
        return partyTypeName;
    }

    public void setPartyTypeName(String partyTypeName) {
        this.partyTypeName = partyTypeName;
    }
    public String getPartyCode() {
        return partyCode;
    }

    public void setPartyCode(String partyCode) {
        this.partyCode = partyCode;
    }
    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }
    public String getAgentOrgName() {
        return agentOrgName;
    }

    public void setAgentOrgName(String agentOrgName) {
        this.agentOrgName = agentOrgName;
    }
    public String getAgentPhone() {
        return agentPhone;
    }

    public void setAgentPhone(String agentPhone) {
        this.agentPhone = agentPhone;
    }


    public Long getAgentOrgId() {
        return agentOrgId;
    }

    public void setAgentOrgId(Long agentOrgId) {
        this.agentOrgId = agentOrgId;
    }

    public Long getPartyProjectId() {
        return partyProjectId;
    }

    public void setPartyProjectId(Long partyProjectId) {
        this.partyProjectId = partyProjectId;
    }

    public String getPartyProjectName() {
        return partyProjectName;
    }

    public void setPartyProjectName(String partyProjectName) {
        this.partyProjectName = partyProjectName;
    }

    public Long getLinkmanId() {
        return linkmanId;
    }

    public void setLinkmanId(Long linkmanId) {
        this.linkmanId = linkmanId;
    }

    public String getLinkmanName() {
        return linkmanName;
    }

    public void setLinkmanName(String linkmanName) {
        this.linkmanName = linkmanName;
    }

    public String getIsMainSuit() {
        return isMainSuit;
    }

    public void setIsMainSuit(String isMainSuit) {
        this.isMainSuit = isMainSuit;
    }

    public Long getPartyId() {
        return partyId;
    }

    public void setPartyId(Long partyId) {
        this.partyId = partyId;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }
}
